===============================
Address Formatter
===============================
Python module to parse and render postal addresses respecting country standard

Requirements
============

Package requirements are handled using pip. To install them do

```
pip install -r requirements.txt
```
